==> haskell-persistent-2.10.4-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent
version: 2.10.4
id: persistent-2.10.4-FmLV1YMIfDTLIGh748uiF6
key: persistent-2.10.4-FmLV1YMIfDTLIGh748uiF6
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.
category: Database, Yesod
abi: 34e8df6fb1b78f5ddf9231c65a891d86
exposed: True
exposed-modules:
    Database.Persist Database.Persist.Class Database.Persist.Quasi
    Database.Persist.Sql Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.Types
hidden-modules: Database.Persist.Types.Base
                Database.Persist.Class.DeleteCascade
                Database.Persist.Class.PersistEntity
                Database.Persist.Class.PersistQuery
                Database.Persist.Class.PersistUnique
                Database.Persist.Class.PersistConfig
                Database.Persist.Class.PersistField
                Database.Persist.Class.PersistStore Database.Persist.Sql.Migration
                Database.Persist.Sql.Internal Database.Persist.Sql.Types
                Database.Persist.Sql.Raw Database.Persist.Sql.Run
                Database.Persist.Sql.Class Database.Persist.Sql.Orphan.PersistQuery
                Database.Persist.Sql.Orphan.PersistStore
                Database.Persist.Sql.Orphan.PersistUnique
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-2.10.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-2.10.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-2.10.4
hs-libraries: HSpersistent-2.10.4-FmLV1YMIfDTLIGh748uiF6
depends:
    aeson-1.4.6.0-IYkWE2kAqOg3BtypRoad0s
    attoparsec-0.13.2.3-7zk58GWWjTj9W2Qd2JktwB base-4.12.0.0
    base64-bytestring-1.0.0.2-2qZIU8NhrUrEe5vir8mbZ5
    blaze-html-0.9.1.2-3rCj4yYYlH244V10MP4Bb5 bytestring-0.10.8.2
    conduit-1.3.1.2-KNywdU6deAEKB3TItOoWtt containers-0.6.0.1
    fast-logger-3.0.0-HqUM5fOGHVE8SZHSb78hy7
    http-api-data-0.4.1.1-Uqth8wLUhbHyxtQHYkCoQ
    monad-logger-0.3.31-6NsHkoUGsUU6puDnRXD7Jc mtl-2.2.2
    path-pieces-0.2.1-7jseLTOU0PkHMQiwNvt0jG
    resource-pool-0.2.3.2-FRXAc737jvM8JDkvVh0Fez
    resourcet-1.2.2-2dmcTwjPeuF8zenLvwytIP
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    silently-1.2.5.1-HV58wYq1AzTJ5xHQM00m1K template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    unliftio-0.2.12-EZdNAvVHW1A5uRUDx4sbmX
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-98MsUmwXpKo1DE5wGxzrlx
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html: /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-2.10.4-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent
version: 2.10.4
id: persistent-2.10.4-7QeSPEA638ZJE8mBsL1Kco
key: persistent-2.10.4-7QeSPEA638ZJE8mBsL1Kco
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.
category: Database, Yesod
abi: cbd24132f79c4fabeda1889ad70670a2
exposed: True
exposed-modules:
    Database.Persist Database.Persist.Class Database.Persist.Quasi
    Database.Persist.Sql Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.Types
hidden-modules: Database.Persist.Types.Base
                Database.Persist.Class.DeleteCascade
                Database.Persist.Class.PersistEntity
                Database.Persist.Class.PersistQuery
                Database.Persist.Class.PersistUnique
                Database.Persist.Class.PersistConfig
                Database.Persist.Class.PersistField
                Database.Persist.Class.PersistStore Database.Persist.Sql.Migration
                Database.Persist.Sql.Internal Database.Persist.Sql.Types
                Database.Persist.Sql.Raw Database.Persist.Sql.Run
                Database.Persist.Sql.Class Database.Persist.Sql.Orphan.PersistQuery
                Database.Persist.Sql.Orphan.PersistStore
                Database.Persist.Sql.Orphan.PersistUnique
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-2.10.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-2.10.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-2.10.4
hs-libraries: HSpersistent-2.10.4-7QeSPEA638ZJE8mBsL1Kco
depends:
    aeson-1.4.6.0-ByJnT4jukmB1Ih4DIu8bQB
    attoparsec-0.13.2.3-8w0M5Ys1O3I8OHsDdXIpYC base-4.12.0.0
    base64-bytestring-1.0.0.2-1pJ47W6BS1G488RuKaCUFo
    blaze-html-0.9.1.2-46zU1Jl1PZV3zFjN4bwuoM bytestring-0.10.8.2
    conduit-1.3.1.2-FrtJMTY3M2CAC8GVZl6Z8t containers-0.6.0.1
    fast-logger-3.0.0-KXxH30LAkKN1DXlXTDCSgx
    http-api-data-0.4.1.1-BmC1PqDXI8MAiNE1OB2bpb
    monad-logger-0.3.31-1KLw0xA9VBN3o0piHDrrdG mtl-2.2.2
    path-pieces-0.2.1-7jseLTOU0PkHMQiwNvt0jG
    resource-pool-0.2.3.2-IAoyPiFBos586Bxmdqt9IZ
    resourcet-1.2.2-B6MNSo3GKFWL8hVHO97lMf
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    silently-1.2.5.1-HV58wYq1AzTJ5xHQM00m1K template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    unliftio-0.2.12-A1Gsmj9ZKmI3R6gP4drz58
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-EKmGslSZSRGGEQm9fn2qPS
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html: /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
